@@ -47,6 +47,7 @@
 #include "gdb_bfd.h"
 #include "btrace.h"
 #include "gdbsupport/pathstuff.h"
+#include "stack.h"
 
 #include <algorithm>
 
@@ -87,13 +88,7 @@ objfile_pspace_info::~objfile_pspace_info ()
 static struct objfile_pspace_info *
 get_objfile_pspace_data (struct program_space *pspace)
 {
-  struct objfile_pspace_info *info;
-
-  info = objfiles_pspace_data.get (pspace);
-  if (info == NULL)
-    info = objfiles_pspace_data.emplace (pspace);
-
-  return info;
+  return &objfiles_pspace_data.try_emplace (pspace);
 }
 
 
@@ -289,34 +284,6 @@ objfile::objfile (gdb_bfd_ref_ptr bfd_, program_space *pspace,
   set_objfile_per_bfd (this);
 }
 
-/* See objfiles.h.  */
-
-int
-entry_point_address_query (program_space *pspace, CORE_ADDR *entry_p)
-{
-  objfile *objf = pspace->symfile_object_file;
-  if (objf == NULL || !objf->per_bfd->ei.entry_point_p)
-    return 0;
-
-  int idx = objf->per_bfd->ei.the_bfd_section_index;
-  *entry_p = objf->per_bfd->ei.entry_point + objf->section_offsets[idx];
-
-  return 1;
-}
-
-/* See objfiles.h.  */
-
-CORE_ADDR
-entry_point_address (program_space *pspace)
-{
-  CORE_ADDR retval;
-
-  if (!entry_point_address_query (pspace, &retval))
-    error (_("Entry point address is not known."));
-
-  return retval;
-}
-
 separate_debug_iterator &
 separate_debug_iterator::operator++ ()
 {
@@ -491,6 +458,13 @@ objfile::~objfile ()
      and if so, call clear_current_source_symtab_and_line.  */
   clear_current_source_symtab_and_line (this);
 
+  /* Check if last_displayed_symtab_info belongs to this objfile,
+     and if so, call clear_last_displayed_sal.  */
+  if (symtab *last_displayed_symtab = get_last_displayed_symtab ();
+      last_displayed_symtab != nullptr
+      && last_displayed_symtab->compunit ()->objfile () == this)
+    clear_last_displayed_sal ();
+
   /* Rebuild section map next time we need it.  */
   auto info = objfiles_pspace_data.get (pspace ());
   if (info != nullptr)
@@ -637,31 +611,6 @@ objfile::has_symbols ()
   return false;
 }
 
-/* See objfiles.h.  */
-
-bool
-have_partial_symbols (program_space *pspace)
-{
-  for (objfile &ofp : pspace->objfiles ())
-    if (ofp.has_partial_symbols ())
-      return true;
-
-  return false;
-}
-
-/* See objfiles.h.  */
-
-bool
-have_full_symbols (program_space *pspace)
-{
-  for (objfile &ofp : pspace->objfiles ())
-    if (ofp.has_full_symbols ())
-      return true;
-
-  return false;
-}
-
-
 /* See objfiles.h.  */
 
 void
@@ -677,18 +626,6 @@ objfile_purge_solibs (program_space *pspace)
     }
 }
 
-/* See objfiles.h.  */
-
-bool
-have_minimal_symbols (program_space *pspace)
-{
-  for (objfile &ofp : pspace->objfiles ())
-    if (ofp.per_bfd->minimal_symbol_count > 0)
-      return true;
-
-  return false;
-}
-
 /* Qsort comparison function.  */
 
 static bool
