@@ -1,6 +1,6 @@
 /* Machine independent support for Solaris /proc (process file system) for GDB.
 
-   Copyright (C) 1999-2019 Free Software Foundation, Inc.
+   Copyright (C) 1999-2026 Free Software Foundation, Inc.
 
    Written by Michael Snyder at Cygnus Solutions.
    Based on work by Fred Fish, Stu Grossman, Geoff Noer, and others.
@@ -24,17 +24,14 @@
  * Pretty-print trace of api calls to the /proc api
  */
 
-#include "defs.h"
-#include "gdbcmd.h"
+#include "cli/cli-cmds.h"
 #include "completer.h"
 
-#define _STRUCTURED_PROC 1
-
 #include <sys/types.h>
 #include <sys/procfs.h>
-#include <sys/proc.h>	/* for struct proc */
-#include <sys/user.h>	/* for struct user */
-#include <fcntl.h>	/* for O_RDWR etc.  */
+#include <sys/proc.h>
+#include <sys/user.h>
+#include <fcntl.h>
 #include "gdbsupport/gdb_wait.h"
 
 #include "proc-utils.h"
@@ -50,16 +47,16 @@ struct trans {
   const char *desc;             /* Short description of value */
 };
 
-static int   procfs_trace    = 0;
+static bool  procfs_trace   = false;
 static FILE *procfs_file     = NULL;
-static char *procfs_filename;
+static std::string procfs_filename = "procfs_trace";
 
 static void
 prepare_to_trace (void)
 {
   if (procfs_trace)			/* if procfs tracing turned on */
     if (procfs_file == NULL)		/* if output file not yet open */
-      procfs_file = fopen (procfs_filename, "a");	/* open output file */
+      procfs_file = fopen (procfs_filename.c_str (), "a");	/* open output file */
 }
 
 static void
@@ -133,12 +130,12 @@ write_with_trace (int fd, void *varg, size_t len, char *file, int line)
 	  break;
 
       if (info_verbose)
-	fprintf (procfs_file ? procfs_file : stdout, 
+	fprintf (procfs_file ? procfs_file : stdout,
 		 "%s:%d -- ", file, line);
       switch (opcode) {
       case PCSET:
-	fprintf (procfs_file ? procfs_file : stdout, 
-		 "write (PCSET,   %s) %s\n", 
+	fprintf (procfs_file ? procfs_file : stdout,
+		 "write (PCSET,   %s) %s\n",
 		 arg[1] == PR_FORK  ? "PR_FORK"  :
 		 arg[1] == PR_RLC   ? "PR_RLC"   :
 		 arg[1] == PR_ASYNC ? "PR_ASYNC" :
@@ -146,8 +143,8 @@ write_with_trace (int fd, void *varg, size_t len, char *file, int line)
 		 info_verbose ? rw_table[i].desc : "");
 	break;
       case PCUNSET:
-	fprintf (procfs_file ? procfs_file : stdout, 
-		 "write (PCRESET, %s) %s\n", 
+	fprintf (procfs_file ? procfs_file : stdout,
+		 "write (PCRESET, %s) %s\n",
 		 arg[1] == PR_FORK  ? "PR_FORK"  :
 		 arg[1] == PR_RLC   ? "PR_RLC"   :
 		 arg[1] == PR_ASYNC ? "PR_ASYNC" :
@@ -155,46 +152,46 @@ write_with_trace (int fd, void *varg, size_t len, char *file, int line)
 		 info_verbose ? rw_table[i].desc : "");
 	break;
       case PCSTRACE:
-	fprintf (procfs_file ? procfs_file : stdout, 
+	fprintf (procfs_file ? procfs_file : stdout,
 		 "write (PCSTRACE) ");
 	proc_prettyfprint_signalset (procfs_file ? procfs_file : stdout,
 				     (sigset_t *) &arg[1], 0);
 	break;
       case PCSFAULT:
-	fprintf (procfs_file ? procfs_file : stdout, 
+	fprintf (procfs_file ? procfs_file : stdout,
 		 "write (PCSFAULT) ");
 	proc_prettyfprint_faultset (procfs_file ? procfs_file : stdout,
 				    (fltset_t *) &arg[1], 0);
 	break;
       case PCSENTRY:
-	fprintf (procfs_file ? procfs_file : stdout, 
+	fprintf (procfs_file ? procfs_file : stdout,
 		 "write (PCSENTRY) ");
 	proc_prettyfprint_syscalls (procfs_file ? procfs_file : stdout,
 				    (sysset_t *) &arg[1], 0);
 	break;
       case PCSEXIT:
-	fprintf (procfs_file ? procfs_file : stdout, 
+	fprintf (procfs_file ? procfs_file : stdout,
 		 "write (PCSEXIT) ");
 	proc_prettyfprint_syscalls (procfs_file ? procfs_file : stdout,
 				    (sysset_t *) &arg[1], 0);
 	break;
       case PCSHOLD:
-	fprintf (procfs_file ? procfs_file : stdout, 
+	fprintf (procfs_file ? procfs_file : stdout,
 		 "write (PCSHOLD) ");
 	proc_prettyfprint_signalset (procfs_file ? procfs_file : stdout,
 				     (sigset_t *) &arg[1], 0);
 	break;
       case PCSSIG:
-	fprintf (procfs_file ? procfs_file : stdout, 
+	fprintf (procfs_file ? procfs_file : stdout,
 		 "write (PCSSIG) ");
 	proc_prettyfprint_signal (procfs_file ? procfs_file : stdout,
-				  arg[1] ? ((siginfo_t *) &arg[1])->si_signo 
-				         : 0, 
+				  arg[1] ? ((siginfo_t *) &arg[1])->si_signo
+					 : 0,
 				  0);
 	fprintf (procfs_file ? procfs_file : stdout, "\n");
 	break;
       case PCRUN:
-	fprintf (procfs_file ? procfs_file : stdout, 
+	fprintf (procfs_file ? procfs_file : stdout,
 		 "write (PCRUN) ");
 	if (arg[1] & PRCSIG)
 	  fprintf (procfs_file ? procfs_file : stdout, "clearSig ");
@@ -206,11 +203,11 @@ write_with_trace (int fd, void *varg, size_t len, char *file, int line)
 	  fprintf (procfs_file ? procfs_file : stdout, "syscallAbort ");
 	if (arg[1] & PRSTOP)
 	  fprintf (procfs_file ? procfs_file : stdout, "stopReq ");
-	  
+
 	fprintf (procfs_file ? procfs_file : stdout, "\n");
 	break;
       case PCKILL:
-	fprintf (procfs_file ? procfs_file : stdout, 
+	fprintf (procfs_file ? procfs_file : stdout,
 		 "write (PCKILL) ");
 	proc_prettyfprint_signal (procfs_file ? procfs_file : stdout,
 				  arg[1], 0);
@@ -219,19 +216,19 @@ write_with_trace (int fd, void *varg, size_t len, char *file, int line)
       default:
 	{
 	  if (rw_table[i].name)
-	    fprintf (procfs_file ? procfs_file : stdout, 
-		     "write (%s) %s\n", 
-		     rw_table[i].name, 
+	    fprintf (procfs_file ? procfs_file : stdout,
+		     "write (%s) %s\n",
+		     rw_table[i].name,
 		     info_verbose ? rw_table[i].desc : "");
 	  else
 	    {
 	      if (lseek_offset != -1)
-		fprintf (procfs_file ? procfs_file : stdout, 
-			 "write (<unknown>, %lud bytes at 0x%08lx) \n", 
+		fprintf (procfs_file ? procfs_file : stdout,
+			 "write (<unknown>, %lud bytes at 0x%08lx) \n",
 			 (unsigned long) len, (unsigned long) lseek_offset);
 	      else
-		fprintf (procfs_file ? procfs_file : stdout, 
-			 "write (<unknown>, %lud bytes) \n", 
+		fprintf (procfs_file ? procfs_file : stdout,
+			 "write (<unknown>, %lud bytes) \n",
 			 (unsigned long) len);
 	    }
 	  break;
@@ -244,10 +241,10 @@ write_with_trace (int fd, void *varg, size_t len, char *file, int line)
   ret = write (fd, (void *) arg, len);
   if (procfs_trace && ret != len)
     {
-      fprintf (procfs_file ? procfs_file : stdout, 
+      fprintf (procfs_file ? procfs_file : stdout,
 	       "[write (%s) FAILED! (%s)]\n",
-	       rw_table[i].name != NULL ? 
-	       rw_table[i].name : "<unknown>", 
+	       rw_table[i].name != NULL ?
+	       rw_table[i].name : "<unknown>",
 	       safe_strerror (errno));
       if (procfs_file)
 	fflush (procfs_file);
@@ -268,8 +265,8 @@ lseek_with_trace (int fd, off_t offset, int whence, char *file, int line)
   lseek_offset = ret;
   if (procfs_trace && (ret == -1 || errno != 0))
     {
-      fprintf (procfs_file ? procfs_file : stdout, 
-	       "[lseek (0x%08lx) FAILED! (%s)]\n", 
+      fprintf (procfs_file ? procfs_file : stdout,
+	       "[lseek (0x%08lx) FAILED! (%s)]\n",
 	       (unsigned long) offset, safe_strerror (errno));
       if (procfs_file)
 	fflush (procfs_file);
@@ -289,18 +286,18 @@ open_with_trace (char *filename, int mode, char *file, int line)
   if (procfs_trace)
     {
       if (info_verbose)
-	fprintf (procfs_file ? procfs_file : stdout, 
+	fprintf (procfs_file ? procfs_file : stdout,
 		 "%s:%d -- ", file, line);
 
       if (errno)
 	{
-	  fprintf (procfs_file ? procfs_file : stdout, 
-		   "[open FAILED! (%s) line %d]\\n", 
+	  fprintf (procfs_file ? procfs_file : stdout,
+		   "[open FAILED! (%s) line %d]\\n",
 		   safe_strerror (errno), line);
 	}
       else
 	{
-	  fprintf (procfs_file ? procfs_file : stdout, 
+	  fprintf (procfs_file ? procfs_file : stdout,
 		   "%d = open (%s, ", ret, filename);
 	  if (mode == O_RDONLY)
 	    fprintf (procfs_file ? procfs_file : stdout, "O_RDONLY) %d\n",
@@ -330,13 +327,13 @@ close_with_trace (int fd, char *file, int line)
   if (procfs_trace)
     {
       if (info_verbose)
-	fprintf (procfs_file ? procfs_file : stdout, 
+	fprintf (procfs_file ? procfs_file : stdout,
 		 "%s:%d -- ", file, line);
       if (errno)
-	fprintf (procfs_file ? procfs_file : stdout, 
+	fprintf (procfs_file ? procfs_file : stdout,
 		 "[close FAILED! (%s)]\n", safe_strerror (errno));
       else
-	fprintf (procfs_file ? procfs_file : stdout, 
+	fprintf (procfs_file ? procfs_file : stdout,
 		 "%d = close (%d)\n", ret, fd);
       if (procfs_file)
 	fflush (procfs_file);
@@ -354,9 +351,9 @@ wait_with_trace (int *wstat, char *file, int line)
   if (procfs_trace)
     {
       if (info_verbose)
-	fprintf (procfs_file ? procfs_file : stdout, 
+	fprintf (procfs_file ? procfs_file : stdout,
 		 "%s:%d -- ", file, line);
-      fprintf (procfs_file ? procfs_file : stdout, 
+      fprintf (procfs_file ? procfs_file : stdout,
 	       "wait (line %d) ", line);
       if (procfs_file)
 	fflush (procfs_file);
@@ -366,10 +363,10 @@ wait_with_trace (int *wstat, char *file, int line)
   if (procfs_trace)
     {
       if (errno)
-	fprintf (procfs_file ? procfs_file : stdout, 
+	fprintf (procfs_file ? procfs_file : stdout,
 		 "[wait FAILED! (%s)]\n", safe_strerror (errno));
       else
-	fprintf (procfs_file ? procfs_file : stdout, 
+	fprintf (procfs_file ? procfs_file : stdout,
 		 "returned pid %d, status 0x%x\n", ret, lstat);
       if (procfs_file)
 	fflush (procfs_file);
@@ -387,7 +384,7 @@ procfs_note (const char *msg, const char *file, int line)
   if (procfs_trace)
     {
       if (info_verbose)
-	fprintf (procfs_file ? procfs_file : stdout, 
+	fprintf (procfs_file ? procfs_file : stdout,
 		 "%s:%d -- ", file, line);
       fprintf (procfs_file ? procfs_file : stdout, "%s", msg);
       if (procfs_file)
@@ -405,19 +402,18 @@ proc_prettyfprint_status (long flags, int why, int what, int thread)
 	fprintf (procfs_file ? procfs_file : stdout,
 		 "Thread %d: ", thread);
 
-      proc_prettyfprint_flags (procfs_file ? procfs_file : stdout, 
+      proc_prettyfprint_flags (procfs_file ? procfs_file : stdout,
 			       flags, 0);
 
       if (flags & (PR_STOPPED | PR_ISTOP))
-	proc_prettyfprint_why (procfs_file ? procfs_file : stdout, 
+	proc_prettyfprint_why (procfs_file ? procfs_file : stdout,
 			       why, what, 0);
       if (procfs_file)
 	fflush (procfs_file);
     }
 }
 
-void
-_initialize_proc_api (void)
+INIT_GDB_FILE (proc_api)
 {
   add_setshow_boolean_cmd ("procfs-trace", no_class, &procfs_trace, _("\
 Set tracing for /proc api calls."), _("\
@@ -426,7 +422,6 @@ Show tracing for /proc api calls."), NULL,
 			   NULL, /* FIXME: i18n: */
 			   &setlist, &showlist);
 
-  procfs_filename = xstrdup ("procfs_trace");
   add_setshow_filename_cmd ("procfs-file", no_class, &procfs_filename, _("\
 Set filename for /proc tracefile."), _("\
 Show filename for /proc tracefile."), NULL,
