@@ -1,6 +1,6 @@
 /* This testcase is part of GDB, the GNU debugger.
 
-   Copyright 2019 Free Software Foundation, Inc.
+   Copyright 2019-2026 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -15,13 +15,6 @@
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
-int
-main (void)
-{
-  asm ("main_label: .globl main_label");
-  return 0;
-}
-
 /* First dummy function.  */
 
 int
@@ -39,3 +32,14 @@ second (char *x)
   asm ("second_label: .globl second_label");
   return 0;
 }
+
+
+int
+main (void)
+{
+  asm ("main_label: .globl main_label");
+
+  first (0);
+  second (0);
+  return 0;
+}
