@@ -1,6 +1,6 @@
 /* Target-dependent code for the Xtensa port of GDB, the GNU debugger.
 
-   Copyright (C) 2003-2022 Free Software Foundation, Inc.
+   Copyright (C) 2003-2026 Free Software Foundation, Inc.
 
    This file is part of GDB.
 
@@ -17,8 +17,8 @@
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
-#ifndef XTENSA_TDEP_H
-#define XTENSA_TDEP_H
+#ifndef GDB_XTENSA_TDEP_H
+#define GDB_XTENSA_TDEP_H
 
 #include "arch/xtensa.h"
 #include "gdbarch.h"
@@ -89,14 +89,14 @@ enum xtensa_target_flags_t
 
 /*  Mask.  */
 
-typedef struct 
+typedef struct
 {
   int reg_num;
   int bit_start;
   int bit_size;
 } xtensa_reg_mask_t;
 
-typedef struct 
+typedef struct
 {
   int count;
   xtensa_reg_mask_t *mask;
@@ -105,7 +105,7 @@ typedef struct
 
 /*  Xtensa register representation.  */
 
-typedef struct 
+typedef struct
 {
   const char *name;            	/* Register name.  */
   int offset;             	/* Offset.  */
@@ -244,9 +244,9 @@ struct xtensa_gdbarch_tdep : gdbarch_tdep_base
 
 #define WB_SHIFT	  2
 
-/* We assign fixed numbers to the registers of the "current" window 
-   (i.e., relative to WB).  The registers get remapped via the reg_map 
-   data structure to their corresponding register in the AR register 
+/* We assign fixed numbers to the registers of the "current" window
+   (i.e., relative to WB).  The registers get remapped via the reg_map
+   data structure to their corresponding register in the AR register
    file (see xtensa-tdep.c).  */
 
-#endif /* XTENSA_TDEP_H */
+#endif /* GDB_XTENSA_TDEP_H */
