@@ -207,7 +207,7 @@ static SIM_RC
 env_set (SIM_DESC sd, const char *arg)
 {
   int i, varlen;
-  char *eq;
+  const char *eq;
   char **envp;
 
   if (STATE_PROG_ENVP (sd) == NULL)
